===========================
Salt 2016.3.3 Release Notes
===========================

Version 2016.3.3 is a bugfix release for :ref:`2016.3.0 <release-2016-3-0>`.

Known Issues
------------

:issue:`36055`: Salt Cloud events (``salt/cloud``) are not generated on the
master event bus when provisioning cloud systems.

`Bootstrap Issue #973`_: ``python-futures`` is not installed when installing from a git tag
on RedHat-based distributions. ``Python futures`` is needed when running Salt with the TCP
transport. This is fixed on the ``develop`` branch of the `salt-bootstrap repo`_ and the fix
will be included in the upcoming release of salt-bootstrap, but is a bug in the bootstrap
release that ships with this version of Salt. Please see the `salt-bootstrap repo`_
for more information on how to update your bootstrap version.

.. _`Bootstrap Issue #973`: https://github.com/saltstack/salt-bootstrap/issues/973
.. _`salt-bootstrap repo`: https://github.com/saltstack/salt-bootstrap

Changes for v2016.3.2..2016.3.3
-------------------------------

Extended changelog courtesy of Todd Stansell (https://github.com/tjstansell/salt-changelogs):

*Generated at: 2016-08-19T16:17:34Z*

Total Merges: **134**

Changes:

- **PR** `#35580`_: (*twangboy*) Fix mac_service attempts to parse non-plist files
- **PR** `#35586`_: (*hu-dabao*) Fix 35420,  add run_on_start in build_schedule_item
- **PR** `#35583`_: (*terminalmage*) Fix localemod tests
- **PR** `#35579`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35577`_: (*terminalmage*) Unit file changes for 2015.8.12, 2016.3.3
- **PR** `#35571`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35566`_: (*rallytime*) Back-port `#35545`_ to 2015.8
- **PR** `#35546`_: (*whiteinge*) Salt api eauth fail gracefully
- **PR** `#35545`_: (*hu-dabao*) `fix-35384`_, fix cmd.run unless
- **PR** `#35540`_: (*rallytime*) Whitespace fix for 2015.8
- **PR** `#35525`_: (*UtahDave*) add missing glob import
- **PR** `#35510`_: (*terminalmage*) Better systemd integration
- **PR** `#35492`_: (*terminalmage*) Clarify config.get docstring
- **PR** `#35483`_: (*gtmanfred*) use __utils__ in salt.cloud
- **PR** `#35573`_: (*rallytime*) Back-port `#33337`_ to 2016.3
- **PR** `#33337`_: (*mzupan*) adding the () to make changes work
- **PR** `#35572`_: (*terminalmage*) Fix poor formatting in pkg state docs
- **PR** `#35545`_: (*hu-dabao*) `fix-35384`_, fix cmd.run unless
- **PR** `#35489`_: (*rallytime*) Back-port `#35463`_ to 2016.3
- **PR** `#35463`_: (*skizunov*) Make `auth_timeout` user configurable again
- **PR** `#35538`_: (*thatch45*) Treat python XML as an optdep
- **PR** `#35526`_: (*thatch45*) Always deploy the thin to /var/tmp
- **PR** `#35522`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35513`_: (*cachedout*) Might be a good idea to be able to download the software we make
- **PR** `#35512`_: (*cachedout*) Fixup 35419
- **PR** `#35508`_: (*terminalmage*) Add Carbon to versionadded for git.diff
- **PR** `#35497`_: (*deepakhj*) Fixes spacing in requirements files
- **PR** `#35302`_: (*Ch3LL*) Add job cache test
- **PR** `#35516`_: (*rallytime*) Back-port `#34441`_ to 2016.3
- **PR** `#34441`_: (*markuskramerIgitt*) Copy and delete silently, do not list each file
- **PR** `#35517`_: (*rallytime*) Back-port `#34502`_ to 2016.3
- **PR** `#34502`_: (*markuskramerIgitt*) Windows installer build scripts will exit on error
- **PR** `#35429`_: (*tankywoo*) Fix iptables target options with no arguments
- **PR** `#35495`_: (*rallytime*) Use correct deprecated notation instead of a warning for apache_module.enable state function.
- **PR** `#35498`_: (*rallytime*) Add supported templates list to all template doc references in file state
- **PR** `#35406`_: (*rallytime*) Provide links to the renderers in the template docs
- **PR** `#35360`_: (*rallytime*) Add all template registery templates to file.managed docs
- **PR** `#35487`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35486`_: (*rallytime*) Update bootstrap script to latest stable (2016.08.16)
- **PR** `#35476`_: (*cachedout*) Fixup SSH bug where sudo without sudo user would break
- **PR** `#35471`_: (*terminalmage*) win_pkg: Fix traceback when package is not installed
- **PR** `#35460`_: (*rallytime*) [2015.8] Update bootstrap script to latest stable (2016.08.15)
- **PR** `#35459`_: (*thatch45*) Ensure that output for salt-ssh gets back
- **PR** `#35453`_: (*theothergraham*) fixes `#34279`_ - disk cache ttl expiry
- **PR** `#35451`_: (*isbm*) Bugfix: zypper mod repo unchanged
- **PR** `#35448`_: (*isbm*) Add ignore_repo_failure option to suppress zypper's exit code 106 on …
- **PR** `#35413`_: (*cachedout*) Resolve path issues with cp.push
- **PR** `#35446`_: (*cachedout*) Make salt-client aware of edge-case where saltutil might be broken
- **PR** `#35449`_: (*dkruger*) aptpkg will specify --install-recommends if enabled by the SLS
- **PR** `#35467`_: (*rallytime*) Back-port `#33518`_ to 2016.3
- **PR** `#35235`_: (*rallytime*) Back-port `#33518`_ to 2016.3
- **PR** `#33518`_: (*tonybaloney*) Fix libcloud bug `#33367`_
- **PR** `#35461`_: (*rallytime*) [2016.3] Update bootstrap script to latest stable (2016.08.15)
- **PR** `#35456`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35442`_: (*cachedout*) Fix cp.push_dir pushing empty dirs
- **PR** `#35436`_: (*cachedout*) Minor doc fixup
- **PR** `#35132`_: (*sjorge*) fixes , causing lots of mayham (onchange) with 2016.3.2 for me
- **PR** `#35447`_: (*ticosax*) [dockerng] RepoTags can be also be None with docker 1.12
- **PR** `#35308`_: (*farcaller*) Actually fixed dockerng.list_tags
- **PR** `#34702`_: (*farcaller*) Fixed dockerng.list_tags
- **PR** `#35427`_: (*cachedout*) Correct errant call to argspec from master. Fix ext_job_cache.
- **PR** `#35428`_: (*cachedout*) Resolve stacktrace logged by highstate outputter if sls cannot be found
- **PR** `#35412`_: (*s0undt3ch*) Only allow one sync read to happen at a time.
- **PR** `#35406`_: (*rallytime*) Provide links to the renderers in the template docs
- **PR** `#35360`_: (*rallytime*) Add all template registery templates to file.managed docs
- **PR** `#35393`_: (*deniszh*) No need to run ddns update every time
- **PR** `#35407`_: (*hu-dabao*) [Fix-35094] None will not be added to grains which generate [none]
- **PR** `#35411`_: (*eliasp*) modules.event.send(): Prevent backtrace for masterless Minions
- **PR** `#35395`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35394`_: (*rallytime*) Back-port `#34573`_ to 2015.8
- **PR** `#35359`_: (*terminalmage*) Clean up open filehandles
- **PR** `#35357`_: (*twangboy*) Fix file.recurse with clean: True  on Windows (2015.8)
- **PR** `#35339`_: (*isbm*) Bugfix: Prevent continuous restart, if a dependency wasn't installed
- **PR** `#34573`_: (*cedwards*) Update freebsd.rst
- **PR** `#35373`_: (*cachedout*) Raise SaltRenderError on bad requisite
- **PR** `#35352`_: (*twangboy*) Fix file.recurse with clean: True  on Windows (2016.3)
- **PR** `#35356`_: (*jfindlay*) document log levels and warn on all logging below info
- **PR** `#35358`_: (*twangboy*) Update libsodium deps
- **PR** `#35360`_: (*rallytime*) Add all template registery templates to file.managed docs
- **PR** `#35362`_: (*rallytime*) Correct deprecation version tags
- **PR** `#35361`_: (*rallytime*) Blockdev deprecations
- **PR** `#25267`_: (*jfindlay*) Disk module improvements
- **PR** `#24893`_: (*The-Loeki*) Contribution: Disk module improvements
- **PR** `#35347`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35325`_: (*kev009*) Fix freebsd netstat route on fbsd 10+
- **PR** `#35323`_: (*thatch45*) Fix issue with bad error check in salt-vt
- **PR** `#35309`_: (*terminalmage*) file.recurse: Do not convert octal mode string to int
- **PR** `#35301`_: (*bobrik*) Pass port to ssh.check_known_host, closes `#35264`_
- **PR** `#35334`_: (*cachedout*) Restore random_master functionality
- **PR** `#35331`_: (*hu-dabao*) fix 35165, salt-run jobs.exit_success jid is broken
- **PR** `#35318`_: (*rallytime*) Remove legacy compat docs in mysql pillar since the code was removed already
- **PR** `#30913`_: (*jtand*) Deprecated code removed.
- **PR** `#35329`_: (*hu-dabao*) sys.doc will skip all not connected minions
- **PR** `#35306`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35290`_: (*terminalmage*) Resolve a couple bugs in orchestration output
- **PR** `#35229`_: (*lubyou*) Ignore import error for pwd module in mac_shadow
- **PR** `#35227`_: (*isbm*) Isbm osfinger ubuntu fix
- **PR** `#35286`_: (*hu-dabao*) fix 34425, a bug that sys.doc cannot output format
- **PR** `#35275`_: (*rallytime*) Back-port `#35213`_ to 2016.3
- **PR** `#35213`_: (*gtmanfred*) add identity v3 support to openstack driver
- **PR** `#35278`_: (*dmurphy18*) Increase timeout for siging to 10 seconds when signing rpm packages
- **PR** `#35276`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35271`_: (*bobrik*) Default state_output_profile to True everywhere, closes `#35166`_
- **PR** `#35249`_: (*terminalmage*) Fix regression in git.latest
- **PR** `#35245`_: (*rallytime*) Back-port `#35039`_ to 2015.8
- **PR** `#35241`_: (*terminalmage*) Ensure max recursion in gitfs results in no blob object being returned.
- **PR** `#35240`_: (*derekmaciel*) Backport `#35225`_ to 2015.8
- **PR** `#35236`_: (*rallytime*) Back-port `#35119`_ to 2015.8
- **PR** `#35233`_: (*terminalmage*) Do not attempt to get fqdn_ip{4,6} grains when ipv{4,6} grains are empty
- **PR** `#35225`_: (*derekmaciel*) Add missing documentation for pkg.installed
- **PR** `#35211`_: (*cachedout*) Alternative sudo users for salt-ssh
- **PR** `#35202`_: (*multani*) doc: fix broken links in the test documentation page
- **PR** `#35119`_: (*derekmaciel*) Assume two EVRs are equal if E and V are equal but one R is missing.
- **PR** `#35039`_: (*whiteinge*) Add saltenv support to module.run
- **PR** `#35274`_: (*rallytime*) Lint fixes for 2016.3 branch
- **PR** `#35232`_: (*theredcat*) fix rabbitmq version detection using a package-agnostic version
- **PR** `#35269`_: (*meaksh*) Checksum validation for zypper pkg.download in 2016.3 and develop
- **PR** `#35197`_: (*vutny*) Make `pkgbuild.repo` state recognize `createrepo` command return code
- **PR** `#35178`_: (*cro*) Add append_minionid_config_dirs option
- **PR** `#35259`_: (*cachedout*) Fixup 35253
- **PR** `#35253`_: (*abednarik*) Fix disk.wipe missing option.
- **PR** `#35253`_: (*abednarik*) Fix disk.wipe missing option.
- **PR** `#35206`_: (*hu-dabao*) Make the log level back to warning for unclassified exc
- **PR** `#35196`_: (*isbm*) Deprecate status.uptime one version later
- **PR** `#35207`_: (*eliasp*) Handle exceptions in `_get_virtual()` and in `_get_virtual()` consumers
- **PR** `#35232`_: (*theredcat*) fix rabbitmq version detection using a package-agnostic version
- **PR** `#35244`_: (*rallytime*) Back-port `#31677`_ to 2016.3
- **PR** `#31677`_: (*miihael*) Return correct value for services that must be enabled in Systemd
- **PR** `#35182`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35174`_: (*rallytime*) Back-port `#35146`_ to 2015.8
- **PR** `#35173`_: (*rallytime*) Back-port `#35135`_ to 2015.8
- **PR** `#35146`_: (*cachedout*) Don't discard running beacons config when listing becaons
- **PR** `#35145`_: (*jacobhammons*) doc version update to 2015.8.11, updates to release notes
- **PR** `#35135`_: (*rallytime*) Add missing CLI Examples to aws_sqs module funcs
- **PR** `#34827`_: (*thatch45*) fix beacon list to include all beacons being processed
- **PR** `#35150`_: (*rallytime*) Start release notes for 2016.3.3
- **PR** `#35157`_: (*hu-dabao*) master returned from func should be a string as designed so far
- **PR** `#35147`_: (*jacobhammons*) doc version updated to 2016.3.2
- **PR** `#35136`_: (*s0undt3ch*) Don't restart processes if the manager is not set to restart them
- **PR** `#35133`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35114`_: (*terminalmage*) Add clarification docs on a common git_pillar misconfiguration
- **PR** `#35043`_: (*rallytime*) Start release notes file for 2015.8.12
- **PR** `#34768`_: (*hrumph*) Fixes `#34767`_
- **PR** `#35120`_: (*kstreee*) The '_handle_event_socket_recv' function in Salt Api is missing first data of stream.
- **PR** `#35131`_: (*rallytime*) Back-port `#35011`_ to 2016.3
- **PR** `#35011`_: (*nishigori*) Fix docstring for code-block of rst
- **PR** `#35110`_: (*hu-dabao*) Do not return job status back to master for master_alive and master_failback schedules
- **PR** `#35104`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35066`_: (*jfindlay*) returners.postgres_local_cache: do not log in __virtual__
- **PR** `#35050`_: (*terminalmage*) [orchestration] Properly handle runner/wheel funcs which accept a 'saltdev' argument
- **PR** `#35026`_: (*cachedout*) Expressly deny a minion if a key cannot be found
- **PR** `#35024`_: (*bobrik*) Cache systemd unit update check per unit, closes `#34927`_
- **PR** `#35105`_: (*rallytime*) Update 2016.3.0 release notes with repo.saltstack.com Xenial pkg availability
- **PR** `#33870`_: (*rallytime*) Add note about Xenial packages to 2016.3.0 release notes
- **PR** `#35059`_: (*vutny*) Add `fun_args` field to events generated by execution of Master modules
- **PR** `#34955`_: (*lubyou*) force dism to always output english text
- **PR** `#35078`_: (*jacobweinstock*) added missing non-keyword argument skip_verify to __get_artifact func…
- **PR** `#35008`_: (*hu-dabao*) Fix multimaster failover on more than two masters and failback behaviour
- **PR** `#35055`_: (*galet*) `#33536`_ pkgrepo.managed does not disable a yum repo with "disabled: True"
- **PR** `#35039`_: (*whiteinge*) Add saltenv support to module.run
- **PR** `#35046`_: (*eliasp*) Prevent backtrace in `salt.states.network`
- **PR** `#35054`_: (*lubyou*) Only fail user lookup is the user parameter is required
- **PR** `#35029`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#35000`_: (*rallytime*) Back-port `#33875`_ and `#34999`_ to 2015.8
- **PR** `#34994`_: (*rallytime*) Back-port `#34835`_ to 2015.8
- **PR** `#34835`_: (*thatch45*) Make the mine and publish combine minion and master opts in salt-ssh
- **PR** `#33875`_: (*jmesquita*) Fix naive fileserver map diff algorithm
- **PR** `#35021`_: (*terminalmage*) Don't add '.' to strerror when passed string ends in ? or !
- **PR** `#34983`_: (*eliasp*) modules.slack.post_message: Allow sending messages to direct-message …
- **PR** `#34996`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#34991`_: (*cachedout*) SSH timeout
- **PR** `#34976`_: (*cachedout*) Refine errors in client
- **PR** `#34831`_: (*thatch45*) If the thin does not match, then redeploy, don't error
- **PR** `#34987`_: (*eliasp*) salt.states.slack: check correct result attribute
- **PR** `#34835`_: (*thatch45*) Make the mine and publish combine minion and master opts in salt-ssh
- **PR** `#34988`_: (*rallytime*) Update release notes with new changes
- **PR** `#34946`_: (*anlutro*) Fix virtualenv behavior when requirements files are in subdirectories
- **PR** `#34957`_: (*sjmh*) Don't fall through to checking auth entries
- **PR** `#34971`_: (*cachedout*) Increase timeout for grains test
- **PR** `#34951`_: (*vutny*) Fix `#34873`_
- **PR** `#34935`_: (*rallytime*) Avoid UnboundLocalError in beacons module
- **PR** `#34894`_: (*rallytime*) [develop] Merge forward from 2016.3 to develop
- **PR** `#34956`_: (*cachedout*) Increase all run_script timeouts to 30s
- **PR** `#34933`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#34916`_: (*cachedout*) Master performance improvement
- **PR** `#34911`_: (*cachedout*) Backport `#34906`_
- **PR** `#34906`_: (*cachedout*) Set timeout for run_salt in test suite
- **PR** `#34898`_: (*hrumph*) Stop multiple refreshes during call to pkg.list_upgrades
- **PR** `#34606`_: (*isbm*) Bugfix: Exit on configuration read (backport)
- **PR** `#34915`_: (*abednarik*) Update service_rh provider to exclude XenServer >= 7.
- **PR** `#34926`_: (*rallytime*) Lint `#34923`_
- **PR** `#34923`_: (*eliasp*) Handle exception when no Slack API key was provided
- **PR** `#34910`_: (*cachedout*) Fix grains error on proxy minions
- **PR** `#34864`_: (*jmacfar*) Check for version in list of installed versions
- **PR** `#34902`_: (*rallytime*) Back-port `#34878`_ to 2016.3
- **PR** `#34878`_: (*abednarik*) Add VirtuozzoLinux is yumpkg enable list.
- **PR** `#34901`_: (*rallytime*) Add VirtuozzoLinux to the list of enabled distros for rpm.py
- **PR** `#34900`_: (*rallytime*) Add VirtuozzoLinux to enabled platforms list in rh_service.py
- **PR** `#34887`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#34869`_: (*terminalmage*) Fail git.latest states with uncommitted changes when force_reset=False
- **PR** `#34862`_: (*thatch45*) Fix salt-ssh cacheing issue
- **PR** `#34859`_: (*cachedout*) Fix wheel test
- **PR** `#34632`_: (*eliasp*) Try to create the log directory when not present yet
- **PR** `#34854`_: (*rallytime*) Remove string_types import from state compiler
- **PR** `#34865`_: (*thatch45*) This needs discussion, since this breaks SUSE
- **PR** `#34858`_: (*rallytime*) [2016.3] Merge forward from 2015.8 to 2016.3
- **PR** `#34847`_: (*cachedout*) Add an option to skip the verification of client_acl users
- **PR** `#34833`_: (*rallytime*) Back-port `#28521`_ to 2015.8
- **PR** `#34828`_: (*thatch45*) Fix `#34648`_
- **PR** `#34827`_: (*thatch45*) fix beacon list to include all beacons being processed
- **PR** `#34823`_: (*rallytime*) Back-port `#25276`_ to 2015.8
- **PR** `#34822`_: (*thatch45*) Fix salt-ssh state.high and state.low
- **PR** `#28521`_: (*gongled*) SPM: packaging doesn't work in Python 2.6. Fixed.
- **PR** `#25276`_: (*jacobhammons*) copy spm.1 man page during setup
- **PR** `#34852`_: (*rallytime*) Skip GCE unit tests - causes test suite to hang

.. _`#18419`: https://github.com/saltstack/salt/issues/18419
.. _`#24745`: https://github.com/saltstack/salt/issues/24745
.. _`#24893`: https://github.com/saltstack/salt/pull/24893
.. _`#25213`: https://github.com/saltstack/salt/issues/25213
.. _`#25267`: https://github.com/saltstack/salt/pull/25267
.. _`#25276`: https://github.com/saltstack/salt/pull/25276
.. _`#26171`: https://github.com/saltstack/salt/issues/26171
.. _`#27294`: https://github.com/saltstack/salt/issues/27294
.. _`#27783`: https://github.com/saltstack/salt/issues/27783
.. _`#28521`: https://github.com/saltstack/salt/pull/28521
.. _`#29785`: https://github.com/saltstack/salt/issues/29785
.. _`#30913`: https://github.com/saltstack/salt/pull/30913
.. _`#31074`: https://github.com/saltstack/salt/issues/31074
.. _`#31677`: https://github.com/saltstack/salt/pull/31677
.. _`#32719`: https://github.com/saltstack/salt/issues/32719
.. _`#32761`: https://github.com/saltstack/salt/issues/32761
.. _`#33337`: https://github.com/saltstack/salt/pull/33337
.. _`#33367`: https://github.com/saltstack/salt/issues/33367
.. _`#33516`: https://github.com/saltstack/salt/issues/33516
.. _`#33518`: https://github.com/saltstack/salt/pull/33518
.. _`#33536`: https://github.com/saltstack/salt/issues/33536
.. _`#33588`: https://github.com/saltstack/salt/issues/33588
.. _`#33620`: https://github.com/saltstack/salt/issues/33620
.. _`#33803`: https://github.com/saltstack/salt/issues/33803
.. _`#33870`: https://github.com/saltstack/salt/pull/33870
.. _`#33875`: https://github.com/saltstack/salt/pull/33875
.. _`#34161`: https://github.com/saltstack/salt/issues/34161
.. _`#34279`: https://github.com/saltstack/salt/issues/34279
.. _`#34425`: https://github.com/saltstack/salt/issues/34425
.. _`#34441`: https://github.com/saltstack/salt/pull/34441
.. _`#34446`: https://github.com/saltstack/salt/issues/34446
.. _`#34481`: https://github.com/saltstack/salt/issues/34481
.. _`#34502`: https://github.com/saltstack/salt/pull/34502
.. _`#34509`: https://github.com/saltstack/salt/issues/34509
.. _`#34526`: https://github.com/saltstack/salt/issues/34526
.. _`#34573`: https://github.com/saltstack/salt/pull/34573
.. _`#34606`: https://github.com/saltstack/salt/pull/34606
.. _`#34632`: https://github.com/saltstack/salt/pull/34632
.. _`#34648`: https://github.com/saltstack/salt/issues/34648
.. _`#34691`: https://github.com/saltstack/salt/issues/34691
.. _`#34702`: https://github.com/saltstack/salt/pull/34702
.. _`#34725`: https://github.com/saltstack/salt/issues/34725
.. _`#34760`: https://github.com/saltstack/salt/issues/34760
.. _`#34767`: https://github.com/saltstack/salt/issues/34767
.. _`#34768`: https://github.com/saltstack/salt/pull/34768
.. _`#34796`: https://github.com/saltstack/salt/issues/34796
.. _`#34798`: https://github.com/saltstack/salt/issues/34798
.. _`#34806`: https://github.com/saltstack/salt/issues/34806
.. _`#34816`: https://github.com/saltstack/salt/issues/34816
.. _`#34822`: https://github.com/saltstack/salt/pull/34822
.. _`#34823`: https://github.com/saltstack/salt/pull/34823
.. _`#34827`: https://github.com/saltstack/salt/pull/34827
.. _`#34828`: https://github.com/saltstack/salt/pull/34828
.. _`#34831`: https://github.com/saltstack/salt/pull/34831
.. _`#34833`: https://github.com/saltstack/salt/pull/34833
.. _`#34835`: https://github.com/saltstack/salt/pull/34835
.. _`#34847`: https://github.com/saltstack/salt/pull/34847
.. _`#34852`: https://github.com/saltstack/salt/pull/34852
.. _`#34854`: https://github.com/saltstack/salt/pull/34854
.. _`#34858`: https://github.com/saltstack/salt/pull/34858
.. _`#34859`: https://github.com/saltstack/salt/pull/34859
.. _`#34861`: https://github.com/saltstack/salt/issues/34861
.. _`#34862`: https://github.com/saltstack/salt/pull/34862
.. _`#34864`: https://github.com/saltstack/salt/pull/34864
.. _`#34865`: https://github.com/saltstack/salt/pull/34865
.. _`#34869`: https://github.com/saltstack/salt/pull/34869
.. _`#34873`: https://github.com/saltstack/salt/issues/34873
.. _`#34878`: https://github.com/saltstack/salt/pull/34878
.. _`#34887`: https://github.com/saltstack/salt/pull/34887
.. _`#34890`: https://github.com/saltstack/salt/issues/34890
.. _`#34893`: https://github.com/saltstack/salt/issues/34893
.. _`#34894`: https://github.com/saltstack/salt/pull/34894
.. _`#34898`: https://github.com/saltstack/salt/pull/34898
.. _`#34900`: https://github.com/saltstack/salt/pull/34900
.. _`#34901`: https://github.com/saltstack/salt/pull/34901
.. _`#34902`: https://github.com/saltstack/salt/pull/34902
.. _`#34906`: https://github.com/saltstack/salt/pull/34906
.. _`#34908`: https://github.com/saltstack/salt/issues/34908
.. _`#34910`: https://github.com/saltstack/salt/pull/34910
.. _`#34911`: https://github.com/saltstack/salt/pull/34911
.. _`#34915`: https://github.com/saltstack/salt/pull/34915
.. _`#34916`: https://github.com/saltstack/salt/pull/34916
.. _`#34923`: https://github.com/saltstack/salt/pull/34923
.. _`#34926`: https://github.com/saltstack/salt/pull/34926
.. _`#34927`: https://github.com/saltstack/salt/issues/34927
.. _`#34933`: https://github.com/saltstack/salt/pull/34933
.. _`#34935`: https://github.com/saltstack/salt/pull/34935
.. _`#34945`: https://github.com/saltstack/salt/issues/34945
.. _`#34946`: https://github.com/saltstack/salt/pull/34946
.. _`#34951`: https://github.com/saltstack/salt/pull/34951
.. _`#34955`: https://github.com/saltstack/salt/pull/34955
.. _`#34956`: https://github.com/saltstack/salt/pull/34956
.. _`#34957`: https://github.com/saltstack/salt/pull/34957
.. _`#34971`: https://github.com/saltstack/salt/pull/34971
.. _`#34976`: https://github.com/saltstack/salt/pull/34976
.. _`#34983`: https://github.com/saltstack/salt/pull/34983
.. _`#34987`: https://github.com/saltstack/salt/pull/34987
.. _`#34988`: https://github.com/saltstack/salt/pull/34988
.. _`#34991`: https://github.com/saltstack/salt/pull/34991
.. _`#34994`: https://github.com/saltstack/salt/pull/34994
.. _`#34996`: https://github.com/saltstack/salt/pull/34996
.. _`#34999`: https://github.com/saltstack/salt/issues/34999
.. _`#35000`: https://github.com/saltstack/salt/pull/35000
.. _`#35003`: https://github.com/saltstack/salt/issues/35003
.. _`#35008`: https://github.com/saltstack/salt/pull/35008
.. _`#35010`: https://github.com/saltstack/salt/issues/35010
.. _`#35011`: https://github.com/saltstack/salt/pull/35011
.. _`#35021`: https://github.com/saltstack/salt/pull/35021
.. _`#35024`: https://github.com/saltstack/salt/pull/35024
.. _`#35026`: https://github.com/saltstack/salt/pull/35026
.. _`#35029`: https://github.com/saltstack/salt/pull/35029
.. _`#35039`: https://github.com/saltstack/salt/pull/35039
.. _`#35043`: https://github.com/saltstack/salt/pull/35043
.. _`#35046`: https://github.com/saltstack/salt/pull/35046
.. _`#35050`: https://github.com/saltstack/salt/pull/35050
.. _`#35051`: https://github.com/saltstack/salt/issues/35051
.. _`#35054`: https://github.com/saltstack/salt/pull/35054
.. _`#35055`: https://github.com/saltstack/salt/pull/35055
.. _`#35059`: https://github.com/saltstack/salt/pull/35059
.. _`#35066`: https://github.com/saltstack/salt/pull/35066
.. _`#35078`: https://github.com/saltstack/salt/pull/35078
.. _`#35094`: https://github.com/saltstack/salt/issues/35094
.. _`#35102`: https://github.com/saltstack/salt/issues/35102
.. _`#35104`: https://github.com/saltstack/salt/pull/35104
.. _`#35105`: https://github.com/saltstack/salt/pull/35105
.. _`#35110`: https://github.com/saltstack/salt/pull/35110
.. _`#35114`: https://github.com/saltstack/salt/pull/35114
.. _`#35119`: https://github.com/saltstack/salt/pull/35119
.. _`#35120`: https://github.com/saltstack/salt/pull/35120
.. _`#35121`: https://github.com/saltstack/salt/issues/35121
.. _`#35131`: https://github.com/saltstack/salt/pull/35131
.. _`#35132`: https://github.com/saltstack/salt/pull/35132
.. _`#35133`: https://github.com/saltstack/salt/pull/35133
.. _`#35135`: https://github.com/saltstack/salt/pull/35135
.. _`#35136`: https://github.com/saltstack/salt/pull/35136
.. _`#35145`: https://github.com/saltstack/salt/pull/35145
.. _`#35146`: https://github.com/saltstack/salt/pull/35146
.. _`#35147`: https://github.com/saltstack/salt/pull/35147
.. _`#35150`: https://github.com/saltstack/salt/pull/35150
.. _`#35157`: https://github.com/saltstack/salt/pull/35157
.. _`#35165`: https://github.com/saltstack/salt/issues/35165
.. _`#35166`: https://github.com/saltstack/salt/issues/35166
.. _`#35173`: https://github.com/saltstack/salt/pull/35173
.. _`#35174`: https://github.com/saltstack/salt/pull/35174
.. _`#35178`: https://github.com/saltstack/salt/pull/35178
.. _`#35182`: https://github.com/saltstack/salt/pull/35182
.. _`#35196`: https://github.com/saltstack/salt/pull/35196
.. _`#35197`: https://github.com/saltstack/salt/pull/35197
.. _`#35202`: https://github.com/saltstack/salt/pull/35202
.. _`#35206`: https://github.com/saltstack/salt/pull/35206
.. _`#35207`: https://github.com/saltstack/salt/pull/35207
.. _`#35211`: https://github.com/saltstack/salt/pull/35211
.. _`#35213`: https://github.com/saltstack/salt/pull/35213
.. _`#35214`: https://github.com/saltstack/salt/issues/35214
.. _`#35225`: https://github.com/saltstack/salt/pull/35225
.. _`#35226`: https://github.com/saltstack/salt/issues/35226
.. _`#35227`: https://github.com/saltstack/salt/pull/35227
.. _`#35229`: https://github.com/saltstack/salt/pull/35229
.. _`#35232`: https://github.com/saltstack/salt/pull/35232
.. _`#35233`: https://github.com/saltstack/salt/pull/35233
.. _`#35234`: https://github.com/saltstack/salt/issues/35234
.. _`#35235`: https://github.com/saltstack/salt/pull/35235
.. _`#35236`: https://github.com/saltstack/salt/pull/35236
.. _`#35240`: https://github.com/saltstack/salt/pull/35240
.. _`#35241`: https://github.com/saltstack/salt/pull/35241
.. _`#35244`: https://github.com/saltstack/salt/pull/35244
.. _`#35245`: https://github.com/saltstack/salt/pull/35245
.. _`#35249`: https://github.com/saltstack/salt/pull/35249
.. _`#35253`: https://github.com/saltstack/salt/pull/35253
.. _`#35259`: https://github.com/saltstack/salt/pull/35259
.. _`#35264`: https://github.com/saltstack/salt/issues/35264
.. _`#35269`: https://github.com/saltstack/salt/pull/35269
.. _`#35271`: https://github.com/saltstack/salt/pull/35271
.. _`#35274`: https://github.com/saltstack/salt/pull/35274
.. _`#35275`: https://github.com/saltstack/salt/pull/35275
.. _`#35276`: https://github.com/saltstack/salt/pull/35276
.. _`#35278`: https://github.com/saltstack/salt/pull/35278
.. _`#35286`: https://github.com/saltstack/salt/pull/35286
.. _`#35290`: https://github.com/saltstack/salt/pull/35290
.. _`#35296`: https://github.com/saltstack/salt/issues/35296
.. _`#35301`: https://github.com/saltstack/salt/pull/35301
.. _`#35302`: https://github.com/saltstack/salt/pull/35302
.. _`#35306`: https://github.com/saltstack/salt/pull/35306
.. _`#35308`: https://github.com/saltstack/salt/pull/35308
.. _`#35309`: https://github.com/saltstack/salt/pull/35309
.. _`#35318`: https://github.com/saltstack/salt/pull/35318
.. _`#35323`: https://github.com/saltstack/salt/pull/35323
.. _`#35325`: https://github.com/saltstack/salt/pull/35325
.. _`#35329`: https://github.com/saltstack/salt/pull/35329
.. _`#35331`: https://github.com/saltstack/salt/pull/35331
.. _`#35334`: https://github.com/saltstack/salt/pull/35334
.. _`#35336`: https://github.com/saltstack/salt/issues/35336
.. _`#35339`: https://github.com/saltstack/salt/pull/35339
.. _`#35347`: https://github.com/saltstack/salt/pull/35347
.. _`#35352`: https://github.com/saltstack/salt/pull/35352
.. _`#35356`: https://github.com/saltstack/salt/pull/35356
.. _`#35357`: https://github.com/saltstack/salt/pull/35357
.. _`#35358`: https://github.com/saltstack/salt/pull/35358
.. _`#35359`: https://github.com/saltstack/salt/pull/35359
.. _`#35360`: https://github.com/saltstack/salt/pull/35360
.. _`#35361`: https://github.com/saltstack/salt/pull/35361
.. _`#35362`: https://github.com/saltstack/salt/pull/35362
.. _`#35373`: https://github.com/saltstack/salt/pull/35373
.. _`#35380`: https://github.com/saltstack/salt/issues/35380
.. _`#35384`: https://github.com/saltstack/salt/issues/35384
.. _`#35387`: https://github.com/saltstack/salt/issues/35387
.. _`#35393`: https://github.com/saltstack/salt/pull/35393
.. _`#35394`: https://github.com/saltstack/salt/pull/35394
.. _`#35395`: https://github.com/saltstack/salt/pull/35395
.. _`#35403`: https://github.com/saltstack/salt/issues/35403
.. _`#35406`: https://github.com/saltstack/salt/pull/35406
.. _`#35407`: https://github.com/saltstack/salt/pull/35407
.. _`#35411`: https://github.com/saltstack/salt/pull/35411
.. _`#35412`: https://github.com/saltstack/salt/pull/35412
.. _`#35413`: https://github.com/saltstack/salt/pull/35413
.. _`#35420`: https://github.com/saltstack/salt/issues/35420
.. _`#35422`: https://github.com/saltstack/salt/issues/35422
.. _`#35423`: https://github.com/saltstack/salt/issues/35423
.. _`#35427`: https://github.com/saltstack/salt/pull/35427
.. _`#35428`: https://github.com/saltstack/salt/pull/35428
.. _`#35429`: https://github.com/saltstack/salt/pull/35429
.. _`#35436`: https://github.com/saltstack/salt/pull/35436
.. _`#35442`: https://github.com/saltstack/salt/pull/35442
.. _`#35446`: https://github.com/saltstack/salt/pull/35446
.. _`#35447`: https://github.com/saltstack/salt/pull/35447
.. _`#35448`: https://github.com/saltstack/salt/pull/35448
.. _`#35449`: https://github.com/saltstack/salt/pull/35449
.. _`#35451`: https://github.com/saltstack/salt/pull/35451
.. _`#35453`: https://github.com/saltstack/salt/pull/35453
.. _`#35456`: https://github.com/saltstack/salt/pull/35456
.. _`#35458`: https://github.com/saltstack/salt/issues/35458
.. _`#35459`: https://github.com/saltstack/salt/pull/35459
.. _`#35460`: https://github.com/saltstack/salt/pull/35460
.. _`#35461`: https://github.com/saltstack/salt/pull/35461
.. _`#35463`: https://github.com/saltstack/salt/pull/35463
.. _`#35467`: https://github.com/saltstack/salt/pull/35467
.. _`#35471`: https://github.com/saltstack/salt/pull/35471
.. _`#35476`: https://github.com/saltstack/salt/pull/35476
.. _`#35483`: https://github.com/saltstack/salt/pull/35483
.. _`#35486`: https://github.com/saltstack/salt/pull/35486
.. _`#35487`: https://github.com/saltstack/salt/pull/35487
.. _`#35489`: https://github.com/saltstack/salt/pull/35489
.. _`#35492`: https://github.com/saltstack/salt/pull/35492
.. _`#35495`: https://github.com/saltstack/salt/pull/35495
.. _`#35497`: https://github.com/saltstack/salt/pull/35497
.. _`#35498`: https://github.com/saltstack/salt/pull/35498
.. _`#35508`: https://github.com/saltstack/salt/pull/35508
.. _`#35510`: https://github.com/saltstack/salt/pull/35510
.. _`#35512`: https://github.com/saltstack/salt/pull/35512
.. _`#35513`: https://github.com/saltstack/salt/pull/35513
.. _`#35516`: https://github.com/saltstack/salt/pull/35516
.. _`#35517`: https://github.com/saltstack/salt/pull/35517
.. _`#35522`: https://github.com/saltstack/salt/pull/35522
.. _`#35525`: https://github.com/saltstack/salt/pull/35525
.. _`#35526`: https://github.com/saltstack/salt/pull/35526
.. _`#35538`: https://github.com/saltstack/salt/pull/35538
.. _`#35540`: https://github.com/saltstack/salt/pull/35540
.. _`#35545`: https://github.com/saltstack/salt/pull/35545
.. _`#35546`: https://github.com/saltstack/salt/pull/35546
.. _`#35566`: https://github.com/saltstack/salt/pull/35566
.. _`#35571`: https://github.com/saltstack/salt/pull/35571
.. _`#35572`: https://github.com/saltstack/salt/pull/35572
.. _`#35573`: https://github.com/saltstack/salt/pull/35573
.. _`#35577`: https://github.com/saltstack/salt/pull/35577
.. _`#35579`: https://github.com/saltstack/salt/pull/35579
.. _`#35580`: https://github.com/saltstack/salt/pull/35580
.. _`#35583`: https://github.com/saltstack/salt/pull/35583
.. _`#35586`: https://github.com/saltstack/salt/pull/35586
.. _`bp-25276`: https://github.com/saltstack/salt/pull/25276
.. _`bp-28521`: https://github.com/saltstack/salt/pull/28521
.. _`bp-31677`: https://github.com/saltstack/salt/pull/31677
.. _`bp-33518`: https://github.com/saltstack/salt/pull/33518
.. _`bp-33875`: https://github.com/saltstack/salt/pull/33875
.. _`bp-34441`: https://github.com/saltstack/salt/pull/34441
.. _`bp-34502`: https://github.com/saltstack/salt/pull/34502
.. _`bp-34835`: https://github.com/saltstack/salt/pull/34835
.. _`bp-35039`: https://github.com/saltstack/salt/pull/35039
.. _`bp-35119`: https://github.com/saltstack/salt/pull/35119
.. _`bp-35213`: https://github.com/saltstack/salt/pull/35213
.. _`bp-35225`: https://github.com/saltstack/salt/pull/35225
.. _`bp-35463`: https://github.com/saltstack/salt/pull/35463
.. _`fix-34425`: https://github.com/saltstack/salt/issues/34425
.. _`fix-34890`: https://github.com/saltstack/salt/issues/34890
.. _`fix-34893`: https://github.com/saltstack/salt/issues/34893
.. _`fix-35094`: https://github.com/saltstack/salt/issues/35094
.. _`fix-35165`: https://github.com/saltstack/salt/issues/35165
.. _`fix-35336`: https://github.com/saltstack/salt/issues/35336
.. _`fix-35384`: https://github.com/saltstack/salt/issues/35384
.. _`fix-35420`: https://github.com/saltstack/salt/issues/35420
.. _`fix-35422`: https://github.com/saltstack/salt/issues/35422
.. _`fix-35458`: https://github.com/saltstack/salt/issues/35458
